@@ -289,10 +289,13 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
         size = len(self.tab)
         indexes = range(0, size)
 
+        current_index = self.tabs.currentIndex()
+
         for index in indexes:
             self.tabs.removeTab(size-1-index)
 
         self.titles = ["Emission size",
+                       "Far field emission",
                        "Cross Spectral Density",
                        "Cumulated occupation",
                        "Eigenfunctions",
@@ -309,6 +312,10 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
             tab.setFixedHeight(self.IMAGE_HEIGHT)
             tab.setFixedWidth(self.IMAGE_WIDTH)
 
+        if current_index < 0:
+            current_index = len(self.titles) - 1
+        self.tabs.setCurrentIndex(current_index)
+
     def set_photon_energy(self):
         ebeam = ElectronBeam(energy_in_GeV=self.electron_energy_in_GeV,
                              current=self.ring_current)
@@ -481,9 +488,9 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
             self.plot_data1D(1e6 * abscissas,
                              wf.get_intensity(),
                              progressBarValue=90.0,
-                             tabs_canvas_index=5,
-                             plot_canvas_index=5,
-                             title=self.titles[5],
+                             tabs_canvas_index=6,
+                             plot_canvas_index=6,
+                             title=self.titles[6],
                              xtitle="Spatial Coordinate [$\mu$m]",
                              ytitle="Intensity",
                              calculate_fwhm=True)
@@ -510,11 +517,31 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
                              progressBarValue=progressBarValue,
                              tabs_canvas_index=0,
                              plot_canvas_index=0,
-                             title=self.titles[0],
+                             title=self.titles[0] + " (backpropagated)",
                              xtitle="Spatial Coordinate [$\mu$m]",
                              ytitle="Intensity",
                              calculate_fwhm=True)
 
+            #
+            # plot emission size
+            #
+            if self.flag_gsm:
+                pass
+            else:
+                wfr = self.coherent_mode_decomposition.far_field_wavefront
+                abscissas = wfr.get_abscissas()
+                intensity = wfr.get_intensity()
+                self.plot_data1D(1e6 * abscissas,
+                                 intensity,
+                                 progressBarValue=progressBarValue,
+                                 tabs_canvas_index=1,
+                                 plot_canvas_index=1,
+                                 title=self.titles[1],
+                                 xtitle="Spatial Coordinate [$\mu$m]",
+                                 ytitle="Intensity at far field (%g m)" % self.coherent_mode_decomposition.distance_to_screen,
+                                 calculate_fwhm=True)
+
+
             #
             # plot CSD
             #
@@ -523,10 +550,10 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
             self.plot_data2D(numpy.abs(CSD),
                              1e6 * abscissas,
                              1e6 * abscissas,
-                             progressBarValue, 1, 1,
-                             title=self.titles[1],
+                             progressBarValue, 2, 1,
+                             title=self.titles[2],
                              xtitle="Spatial Coordinate x1 [$\mu$m]",
-                             ytitle="Spatial Coordinate x1 [$\mu$m]")
+                             ytitle="Spatial Coordinate x2 [$\mu$m]")
 
             #
             # plot cumulated occupation
@@ -543,9 +570,9 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
             self.plot_data1D(x,
                              cumulated_occupation,
                              progressBarValue=progressBarValue,
-                             tabs_canvas_index=2,
-                             plot_canvas_index=2,
-                             title=self.titles[2],
+                             tabs_canvas_index=3,
+                             plot_canvas_index=3,
+                             title=self.titles[3],
                              xtitle="mode index",
                              ytitle="Cumulated occupation",
                              calculate_fwhm=False)
@@ -567,9 +594,9 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
             self.plot_multi_data1D(1e6*abscissas,
                              y_list,
                              progressBarValue=progressBarValue,
-                             tabs_canvas_index=3,
-                             plot_canvas_index=3,
-                             title=self.titles[3],
+                             tabs_canvas_index=4,
+                             plot_canvas_index=4,
+                             title=self.titles[4],
                              xtitle="x [um]",
                              ytitles=ytitles,
                              colors=colors,
@@ -595,9 +622,9 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
             self.plot_multi_data1D(1e6 * abscissas,
                              [SD,numpy.real(y)],
                              progressBarValue=progressBarValue,
-                             tabs_canvas_index=4,
-                             plot_canvas_index=4,
-                             title=self.titles[4],
+                             tabs_canvas_index=5,
+                             plot_canvas_index=5,
+                             title=self.titles[5],
                              xtitle="x [um]",
                              ytitles=["SD from CSD","SD from modes"],
                              colors=colors)
@@ -610,7 +637,6 @@ class OWUndulatorCoherentModeDecomposition1D(WofryWidget):
 
 
 
-
 if __name__ == "__main__":
     import sys
     from PyQt5.QtWidgets import QApplication
